<!-- 前台头部 -->
<template>
  <el-header>
    <div class="header-container">
      <div class="header-left">
        <div class="logo-box">
          <!--     logo     -->
          <img class="logo" src="../../../assets/img/logo-lj-white.png" alt="">

          <!--     logo文字     -->
          <div class="logo_title" :style="$i18n.locale === 'en-US' ? { fontSize: '18px' } : ''"
               @click="_ => _ && goIndex">
            <span class="chinese">{{ systemInformation.name }}</span>
            <span class="english">{{ systemInformation.desc }}</span>
          </div>

          <!--      菜单    -->
          <div :class="['menu-box'] ">
            <div class="short-menu">
              <div class="home-icon" @click="menuClick(homePageInfo)">
                <el-tooltip placement="bottom"
                            trigger="hover"
                            popper-class="menu-popover">
                  <span slot="content">{{ homePageInfo.name }}</span>
                  <svgIcon icon-style="icon header-icon"
                           :icon-class="homePageInfo.menuIcon ? homePageInfo.menuIcon : ''"
                           :title="homePageInfo.name" />
                </el-tooltip>
              </div>
              <div class="more-box" @mousedown.prevent="moreClick">
                <template>
                  <el-tooltip placement="right"
                              trigger="hover"
                              popper-class="menu-popover">
                    <span slot="content">{{ showMore ? '收起' : '显示' }}菜单</span>
                    <div v-if="currentMenu === 'homePage' || customSystemRouter.some(i => i.path === currentMenu) "
                         :class="['reference-box-collapse', showMore ? 'expansion' : '']"
                    >
                      <span></span>
                    </div>
                    <div v-else
                         :class="['reference-box', showMore ? 'expansion' : '']">
                      <svgIcon icon-style="icon header-icon"
                               :icon-class="currentMenuInfo.menuIcon ? currentMenuInfo.menuIcon : ''" />
                      <span>{{ currentMenuInfo.name }}</span>
                    </div>
                  </el-tooltip>
                </template>
              </div>
            </div>
            <div :class="['all-menu', showMore ? 'all-menu-show' :'']">
              <div class="all-menu-content" tabindex="-1" @blur="allMenuBlur" ref="allNavContent">
                <div :class="['menu-btn',item.alias === currentMenu? 'menu-btn-active' :'']"
                     v-for="item in businessMenu.slice(1)"
                     :key="item.alias"
                     @click="menuClick(item)"
                >
                  <svgIcon icon-style="icon header-icon" :icon-class="item.menuIcon ? item.menuIcon : ''" />
                  <span> {{ item.name }}</span>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
      <div class="header-right">
        <div class="bell-box" @click="showMsgDrawer = true">
          <el-badge :hidden="!newMsgNum" v-model="newMsgNum" class="bell">
            <el-tooltip placement="left"
                        trigger="hover"
                        popper-class="menu-popover">
              <span slot="content">消息中心</span>
              <img
                src="../../../assets/img/publicLayout/bell.png"
                alt=""
              />
            </el-tooltip>
          </el-badge>
        </div>
        <HtAvatar class="avatar" :user="currentUser" />
        <el-popover popper-class="header-popper" width="250" placement="bottom" trigger="hover">
          <div slot="reference" class="user-box">
            <div class="welcome">你好，{{ userInfo && userInfo.username }}<i class="el-icon-caret-bottom" />
            </div>
            <div class="department">{{ companyDepartment }}</div>
          </div>
          <div class="user-box-header">
            <h3 v-if="userInfo">
              {{ userInfo && userInfo.username }}
            </h3>
          </div>
          <ul class="user-link-ul">
            <li @click="openPersonalCenter">
              <i class="el-icon-user"></i>
              {{ $t('navigator.personalCenter') }}
            </li>
            <li @click="openResetPwdDialog">
              <i class="el-icon-setting"></i>
              {{ $t('navigator.changePsd') }}
            </li>
            <li v-if="userType !== 2" @click="handleSysPlat">
              <i class="el-icon-monitor" />
              {{ $t('navigator.manageSys') }}
            </li>
            <li @click="logout">
              <i class="el-icon-circle-close" />
              {{ $t('navigator.signOut') }}
            </li>
          </ul>
        </el-popover>
      </div>
    </div>

    <!--  消息抽屉组件  -->
    <message-drawer
      :showMsgDrawer.sync="showMsgDrawer"
      :newMsgNum.sync="newMsgNum"
    />
  </el-header>
</template>

<script>
import HtAvatar from '@/components/common/HtAvatar.vue'
import langSelect from '@/components/langSelect/index.vue'
import {mapState} from 'vuex'
import MessageDrawer from '@/components/layout/Navigator/components/MessageDrawer.vue'
import customSystemRouter from '@/router/custom-system-router'

export default {
  name: 'Navigator',
  components: {MessageDrawer, HtAvatar, langSelect},
  props: {
    currentMenu: {
      default: '',
      type: String
    }
  },
  computed: {
    ...mapState({
      currentUser: (state) => state.user.currentUserDetail,
      token: (state) => state.login.currentUser.token,
      // 重构菜单信息
      businessMenu(state) {
        return state.menu.frontMenus.find(i => i.alias === 'normal')?.children || []
      },
      homePageInfo() {
        return this.businessMenu[0] || {}
      },
      userType() {
        if (this.currentUser && this.currentUser.user) {
          return this.currentUser.user.userType
        }
      },
      userInfo: state => state.login.currentUser,
      companyDepartment: state => {
        /*
          判断isCurrent去找到是否存在1的，则判断是不是所有值都一样，
          如果有一样的话取第一项。如果没有则去判断isMaster，
          如果isCurrent，isMaster都不符合条件。取org数组的第一项中的数据
        */
        const org = state.user.currentUserDetail?.org || []
        if (!(Array.isArray(org) && org.length)) return ''
        let resultObj
        const isCurrentArr = org.filter(i => i.isCurrent === 1)
        const isMasterArr = org.filter(i => i.isMaster === 1)
        if (isCurrentArr.length) {
          resultObj = isCurrentArr[0]
        } else if (isMasterArr.length) {
          resultObj = isMasterArr[0]
        } else {
          resultObj = org[0]
        }
        const {orgName, deptName} = resultObj || {}
        return [orgName, deptName].filter(i => i).join('-') || ''
      }
    }),
    currentMenuInfo() {
      return this.businessMenu.find(i => i.alias === this.currentMenu) || {}
    }
  },
  data() {
    return {
      systemInformation: {},
      showMore: false, // 展示全部菜单
      showMsgDrawer: false, // 是否展示侧边栏消息抽屉
      customSystemRouter, // 自定义后台路由
      newMsgNum: 0 // 新消息数量
    }
  },
  created() {
  },
  mounted() {
    !this.currentUser && this.$store.dispatch('user/loadCurrentUserDetail')
    let url = '${uc}/uc/tenantManage/v1/getTenantByCode?code=platform'
    this.$http.get(url).then((resp) => this.systemInformation = resp.data || {})
  },
  methods: {
    goIndex() {
      let frontMenus = JSON.parse(sessionStorage.getItem('currentFrontMenus')) || false
      let bigScreen = frontMenus.filter(item => item.alias === 'bigScreen')
      let alise = bigScreen[0].children[0].alias
      this.$router.push({path: `/${alise}`})
    },

    // 修改密码页面
    openResetPwdDialog() {
      this.$router.push({
        path: '/platLayout/resetPwdView',
        query: {type: 'settings'}
      })
    },

    // 跳转个人中心
    openPersonalCenter() {
      this.$router.push({
        path: '/platLayout/PersonalInfo'
      })
    },

    // 跳转管理系统
    handleSysPlat() {
      let url = window.context.manage + '/getAuth?token=' + this.token
      window.open(url, '_blank')
    },

    // 退出登录
    logout() {
      this.$store.dispatch('menu/clearMenus')
      this.$store.dispatch('user/clearUser')
      this.$store.dispatch('menu/setCopyMenus', [])
      let loginRouthPath =
        localStorage.getItem(
          this.$store.state.login.currentUser.account +
          'loginRoutePath'
        ) || '/login'
      this.$store.dispatch('login/logoutAndCleanUp').then(() => {
        switch (window.ssoConfig.mode) {
          case 'cas':
          case 'oauth':
            window.sessionStorage.removeItem('currentUser')
            window.location.href =
              window.ssoConfig.logout +
              '?service=' +
              window.location.href.split('?')[0]
            break
          default:

            this.$router.push({
              path: loginRouthPath
            })
            break
        }
      })
    },

    // 更多nav点击
    moreClick() {
      if (this.showMore) {
        this.showMore = false
      } else {
        this.showMore = true
        this.$nextTick(_ => {
          this.$refs.allNavContent && this.$refs.allNavContent.focus()  //获得焦点
        })
      }
    },

    // 菜单弹出层失焦时间
    allMenuBlur() {
      this.$nextTick(_ => this.showMore = false)
    },

    // nav菜单导航点击
    menuClick(item) {
      this.$router.push(item.routerPath)
      this.showMore = false
    }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables';


.title {
  font-family: STXingkai;
  font-size: 35px !important;

  i {
    font-size: 30px;
  }
}

.el-header {
  padding: 0;
  height: 60px !important;
}

.header-container {
  width: 100%;
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: space-between;
  z-index: 999;
  padding-left: 16px;
  box-sizing: border-box;
  background: url("~@/assets/img/publicLayout/header-bg.png") no-repeat 0 0, linear-gradient(180deg, #1150A0 0%, #4686D6 100%);
  background-size: 100% 100%;

  > * {
    font-family: Microsoft YaHei, serif;
  }

  .header-left {
    flex: 1;
    display: flex;
    align-items: center;
    column-gap: 60px;
    height: 100%;
    position: relative;

    .logo-box {
      height: 100%;
      box-sizing: border-box;
      display: flex;
      align-items: center;
      color: #fff;

      .logo {
        width: 65px;
        margin-right: 10px;
      }

      .logo_title {
        cursor: pointer;
        display: flex;
        flex-direction: column;

        .chinese {
          display: inline-block;
          font-size: 18px;
          font-family: SourceHanSerifCN-Medium, serif;
          width: 288px;
          height: 26px;
          color: #FFFFFF;
          line-height: 26px;
        }

        .english {
          display: inline-block;
          font-size: 12px;
          height: 14px;
          font-family: Lato-Regular, serif;
          color: #FFFFFF;
          line-height: 14px;
        }
      }


      .menu-box {
        padding-left: 20px;
        height: 60px;
        margin: 0 0 0 25px;
        position: relative;
        box-sizing: border-box;

        .short-menu {
          width: 100%;
          height: 100%;
          display: flex;
          //justify-content: space-between;
          align-items: center;
          column-gap: 16px;

          .home-icon {
            cursor: pointer;
            height: 32px;
            position: relative;

            svg {
              user-select: none;
              font-size: 33px;
            }
          }

          .more-box {
            height: 100%;
            cursor: pointer;
            display: flex;
            align-items: center;
            position: relative;

            &::before {
              content: '';
              position: absolute;
              width: 1px;
              height: 16px;
              background-color: #F2F8FF;
              left: 0;
              top: 50%;
              transform: translateY(-50%);
            }

            .reference-box-collapse {
              width: 65px;
              height: 100%;
              display: flex;
              align-items: center;
              justify-content: center;
              transition: all 0.2s;
              background-color: transparent;

              span {
                display: inline-block;
                width: 32px;
                height: 32px;
                background: url("~@/assets/img/publicLayout/more-icon.png") no-repeat 50% 70%;
                background-size: 100% 100%;
                transition: all 0.2s;
              }

              &.expansion {
                background-color: #F2F8FF;
                height: 100%;

                span {
                  background: url("~@/assets/img/publicLayout/more-icon-blue.png") no-repeat 50% 70%;
                  background-size: 100% 100%;
                }
              }
            }

            .reference-box {
              height: 100%;
              display: flex;
              align-items: center;
              user-select: none;
              column-gap: 8px;
              white-space: nowrap;
              padding: 0 16px;

              span {
                font-size: 16px;
                font-family: Microsoft YaHei, serif;
                font-weight: 400;
              }

              svg {
                width: 30px;
                height: 28px;
                margin-top: 1px;
              }

              &.expansion {
                background-color: #F2F8FF;
                height: 100%;

                span, svg {
                  color: #1150A0;
                }


              }

            }


          }
        }

        .all-menu {
          position: absolute;
          left: 69px;
          bottom: 0;
          width: 536px;
          height: 0;
          z-index: 1000;
          transition: height .2s, bottom .2s, opacity .1s;
          opacity: 0;
          pointer-events: none;
          overflow: hidden;
          background: #F2F8FF;
          border-radius: 0 0 16px 16px;
          box-shadow: 0 4px 10px 0 rgba(26, 70, 128, 0.3);

          &.all-menu-show {
            bottom: -315px;
            height: 312px;
            opacity: 1;
            pointer-events: auto;
          }

          .all-menu-content {
            width: 100%;
            height: 100%;
            padding: 24px;
            box-sizing: border-box;
            display: flex;
            flex-wrap: wrap;
            column-gap: 8px;
            row-gap: 8px;

            &:focus {
              outline: none;
            }


            .menu-btn {
              width: calc((100% - 24px) / 4);
              height: 130px;
              background: linear-gradient(360deg, #C0DCFF 0%, #F2F8FF 100%);
              border-radius: 8px;
              display: flex;
              flex-direction: column;
              row-gap: 16px;
              align-items: center;
              justify-content: center;
              cursor: pointer;
              transition: all 1s;
              box-sizing: border-box;

              @mixin hover-active {
                background: linear-gradient(360deg, #2767B7 0%, #2767B7 100%);

                span, svg {
                  color: #FFFFFF;
                }
              }

              &:hover {
                @include hover-active
              }

              &.menu-btn-active {
                @include hover-active
              }

              span {
                display: inline-block;
                height: 24px;
                line-height: 24px;
                font-size: 18px;
                font-family: Microsoft YaHei, serif;
                font-weight: 400;
                color: #1150A0;
                transition: all 0.3s;
                user-select: none;

              }

              svg {
                font-size: 42px;
                color: #1150A0;
                transition: all 0.3s;

              }


            }
          }
        }
      }
    }

    .first-menus {
      display: flex;
      column-gap: 30px;
      height: 100%;
      position: absolute;
      left: 58%;
      transform: translateX(-50%);

      .first-menus-item {
        padding-top: 6px;
        height: 100%;
        display: flex;
        align-items: center;
        column-gap: 10px;
        position: relative;
        cursor: pointer;
        transition: all 0.2s;
        color: #FFFFFF;
        user-select: none;
        box-sizing: border-box;


        &.active-menu {
          color: #fff;
          transform: scale(1.125) translateY(-5%);

          span {
            font-weight: 700;

            &::after {
              opacity: 1;
              transform: translate(-50%, 0%)
            }
          }

        }

        &:hover {
          color: #fff;

          span {
            color: #fff;
          }
        }

        span {
          display: flex;
          align-items: center;
          height: 100%;
          font-size: 16px;
          color: #FFFFFF;
          transition: all 0.15s;
          white-space: nowrap;
          position: relative;

          &::after {
            content: '';
            width: 80%;
            height: 2.5px;
            background-color: #fff;
            border-radius: 5px;
            position: absolute;
            bottom: 3px;
            left: 50%;
            transform: translate(-50%, 300%);
            opacity: 0;
            transition: all 0.2s;
          }
        }

        .header-icon {
          font-size: 18px;
        }

        .active-line {
          width: 40px;
          height: 4px;
          border-radius: 2px 2px 2px 2px;
          opacity: 1;
          margin: 5px auto 0;
        }
      }
    }

  }


  .header-right {
    margin-right: 16px;
    display: flex;
    align-items: center;

    .bell-box {
      padding: 10px;
      cursor: pointer;
      user-select: none;

      ::v-deep .bell {
        display: flex;
        align-items: center;

        img {
          width: 24px;
          height: 24px;
          -webkit-user-drag: none;
        }

        .el-badge__content {
          display: flex;
          align-items: center;
          height: 18px;
          border-radius: 100px;
          box-sizing: border-box;
          padding: 0 6px;
          font-size: 12px;
          font-family: Microsoft YaHei, serif;
          font-weight: 400;
          color: #FFFFFF;
        }
      }
    }


    .avatar {
      margin: 0 8px 0 40px;
    }

    .input {
      width: 340px;
      height: 40px;
      border-radius: 4px;
      margin: 19px 36px;
      margin-left: 24px;

      /deep/ .el-input input,
      /deep/ .el-input-group__append {
        background-color: #f1f1f1;
        border: none;

        .el-icon-search {
          font-size: 18px;
        }
      }

      /deep/ .el-input-group {
        height: 100%;
      }

      /deep/ .el-input {
        input {
          font-size: 16px;
          font-weight: normal;
          font-stretch: normal;
          line-height: 19px;
          letter-spacing: 0px;
          height: 100%;
        }

        input::-webkit-input-placeholder {
          // 针对 谷歌 内核
          font-family: Microsoft YaHei;
          font-size: 16px;
          font-weight: normal;
          font-stretch: normal;
          line-height: 19px;
          letter-spacing: 0px;
          color: #c4c4c4;
        }

        input:-moz-placeholder {
          // 火狐
          font-family: Microsoft YaHei;
          font-size: 16px;
          font-weight: normal;
          font-stretch: normal;
          line-height: 19px;
          letter-spacing: 0px;
          color: #c4c4c4;
        }

        input:-ms-input-placeholder {
          // 微软ie
          font-family: Microsoft YaHei;
          font-size: 16px;
          font-weight: normal;
          font-stretch: normal;
          line-height: 19px;
          letter-spacing: 0px;
          color: #c4c4c4;
        }
      }
    }

    .user-box {
      display: flex;
      flex-direction: column;
      margin-right: 10px;
      row-gap: 2px;

      .welcome {
        display: flex;
        align-items: center;
        font-size: 14px;
        font-family: Microsoft YaHei, Microsoft YaHei, serif;
        color: #FFFFFF;
        font-weight: 700;

        i {
          color: #FFFFFF;
          font-size: 14px;
          margin-left: 8px;
        }
      }

      .department {
        font-size: 12px;
        font-family: Microsoft YaHei, Microsoft YaHei, serif;
        font-weight: 400;
        color: #FFFFFF;
      }
    }
  }
}

.operation-manual {
  color: #2761ff;
  background: #e9efff;
  padding: 6px 12px;
  border: 1px solid #a9c0ff;
  cursor: pointer;
  margin-right: 20px;
  font-weight: bold;
  border-radius: 5px;

  i {
    color: #2761ff;
    margin-right: 6px;
  }

  .sub-back {
    color: #fff;
  }

  &:first-child {
    color: #fff;
    background: #2761ff;
    border: 1px solid #2761ff;
  }
}

.action-btn {
  width: 100px;
  height: 35px;
  border-radius: 5px;
  box-sizing: border-box;
  padding: 0;
  margin: 0 10px 0 0;
}

.operation-manual:hover {
  background: #2761ff;
  border-color: #2761ff;
  color: #ffffff;

  i {
    color: #ffffff;
  }
}


.el-avatar {
  width: 30px;
  height: 30px;
}

.el-avatar i {
  font-size: 16px;
  color: #c0c4cc;
}

.user-box-header {
  padding: 10px;

  h3 {
    color: $--navigator-text-color;
    font-weight: bold;
    margin: 2px 0;
  }
}

.user-link-ul {
  list-style: none;
  padding: 0;
  margin: 0;
  background: $--navigator-main-color;

  > li {
    padding: 8px 10px;
    cursor: pointer;
    color: $--navigator-text-color;
  }

  > li > i {
    margin-right: 5px;
    font-size: 16px;
    font-weight: bold;
  }

  > li:hover {
    color: $--navigator-text-color;
    background-color: #f1f1f1;
  }

  .el-link {
    color: #606266 !important;

    i {
      font-size: 16px;
      margin-right: 5px;
      vertical-align: middle;
    }
  }
}

.user-box-logout {
  justify-content: center;
  background: $--navigator-main-color;
  // border-top: 1px solid rgba($--navigator-text-color,0.1);
  // border-bottom: 1px solid rgba($--navigator-text-color,0.1);
  // margin-top: 10px;
  color: $--navigator-main-text-color !important;
}

.user-box-logout:hover {
  background: $--navigator-main-text-color;
}

.user-box-logout > .el-link {
  line-height: 46px;
  width: 100%;
  color: $--navigator-main-text-color !important;
  background: $--navigator-main-color;
}

.user-box-logout > .el-link:hover,
.user-box-logout > .el-link:focus {
  color: $--navigator-main-text-color !important;
}


</style>

<style>
.menu-popover {
  min-width: 0 !important;
}

.header-popper {
  width: 150px !important;
  border-radius: 10px;
  overflow: hidden;
  padding: 8px 12px 16px !important;
  vertical-align: middle;
  right: 50px !important;
  left: initial !important;
  box-shadow: 0 6px 16px 0 rgb(0 0 0 / 10%);

  * {
    font-size: 13px;
  }
}
</style>
